@@ -37,7 +37,9 @@ struct qserver {
     char *outfilename;
     char *query_arg;
     struct query_param *params;
+    unsigned long challenge;
     unsigned short port;
+    unsigned short query_port;
     /** \brief number of retries _left_ for status query or rule query.
      *
      * That means
@@ -71,14 +73,14 @@ struct qserver {
     int n_packets;
 
     /** \brief number of servers in master_pkt
-     * 
+     *
      * normally master_pkt_len/6
      */
     int n_servers;
     /** \brief length of master_pkt */
     int master_pkt_len;
     /** \brief IPs received from master.
-     * 
+     *
      * array of four bytes ip, two bytes port in network byte order
      */
     char *master_pkt;
@@ -178,4 +180,18 @@ int qserver_send(struct qserver* server, const char* data, size_t len);
 
 int send_broadcast( struct qserver *server, const char *pkt, size_t pktlen);
 
+/**
+ * Registers the send of a request packet.
+ *
+ * This updates n_requests, n_packets, packet_time1 and decrements n_retries
+ */
+void register_send( struct qserver *server );
+
+/**
+ * Sends a packet to the server either direct or via broadcast.
+ *
+ * Once sent calls register_send to register the send of the packet
+ */
+int send_packet( struct qserver* server, const char* data, size_t len );
+
 #endif
